==> pitivi_2020.09.2.orig.tar.xz: pitivi-2020.09.2/docs/GSoC_Application.md <==
---
short-description: How to fill out the application to GSoC
...

# Fill out the Application

Once the students applications period has opened (see
[schedule](https://summerofcode.withgoogle.com/how-it-works/#timeline)),
you have to submit your application on Google's Summer of Code website.
Your application must be written in English.

**Copy and paste all questions below into your application form and
answer all of them. Do not skip any question, if you do, your proposal
will be invalid.**

## Mandatory questions to be answered

#### What is your e-mail address and IRC nick?

#### What is your blog address?

*Having a blog is required for a valid proposal. You can create a free
one on, e.g., [wordpress.com](https://wordpress.com),
[gitlab.com](https://gohugo.io/hosting-and-deployment/hosting-on-gitlab/),
etc.*

#### What city and country will you reside in during the summer?

#### What is your academic background?

*Please include university, major, and expected or achieved graduation
date for any degree you have or are pursuing.*

#### Who is a possible mentor for the project you are proposing?

#### What is the ultimate goal of your proposal?

#### What [applications/libraries](Architecture.md) will the proposed work modify or create?

#### What benefits does your proposed work have for the Pitivi/GStreamer/GNOME community?

#### Why are you the right person to work on this project?

#### How do you plan to achieve completion of your project?

*Please provide a sequence of tasks and subtasks and how long (days) you
estimate it will take you to complete each of them.*

#### What are your past experiences with the open source world as a user and as a contributor?

*Please include links to any code you wrote for open source projects.*

#### What other relevant projects have you worked on previously and what knowledge you gained from working on them?

#### What other time commitments, such as school work, exams, research, another job, planned vacation, etc., will you have between May 18th and August 10th?

*Please mention the dates for these commitments and how many hours a
week do these commitments take.*

## Tips

Please be factual and clear in answering these questions. Feel free to
add anything else that is relevant for your application.

It is never too early to start working on your GSoC application! By
large, the most time consuming part of the application is writing the
sequence of tasks for completing the project. Split the work in small
easily approachable parts.

To write a strong application, make sure what you are proposing is a
manageable and agreed-upon project. Demonstrate clearly your knowledge,
skills, and enthusiasm.

==> pitivi_2021.05.orig.tar.xz: pitivi-2021.05/docs/GSoC_Application.md <==
---
short-description: How to fill out the application to GSoC
...

# Fill out the Application

Once the Student Application Period has opened (see
[schedule](https://summerofcode.withgoogle.com/how-it-works/#timeline)),
you have to submit your application on Google's Summer of Code website.
Your application must be written in English.

**Copy and paste all questions below into your application form and
answer all of them. Do not skip any question, if you do, your proposal
will be invalid.**

## Mandatory questions to be answered

#### What is your e-mail address and IRC nick?

#### What is your blog address?

*Having a blog is required for a valid proposal. You can create a free
one on, e.g., [wordpress.com](https://wordpress.com),
[gitlab.com](https://gohugo.io/hosting-and-deployment/hosting-on-gitlab/),
etc.*

#### What city and country will you reside in during the summer?

#### What is your academic background?

*Please include university, major, and expected or achieved graduation
date for any degree you have or are pursuing.*

#### Who is a possible mentor for the project you are proposing?

#### What is the ultimate goal of your proposal?

#### What [applications/libraries](Architecture.md) will the proposed work modify or create?

#### What benefits does your proposed work have for the Pitivi/GStreamer/GNOME community?

#### Why are you the right person to work on this project?

#### How do you plan to achieve completion of your project?

*Please provide a sequence of tasks and subtasks and how long (days) you
estimate it will take you to complete each of them. Think about how to split the
work in small easily approachable parts.*

*Pay attention, this is the most time consuming part of the proposal.*

#### What are your past experiences with the open source world as a user and as a contributor?

*Please include links to any code you wrote for open source projects.*

#### What other relevant projects have you worked on previously and what knowledge you gained from working on them?

#### How do you plan to schedule the work on the project?

*The Coding Period is between June 7th - August 16th. Please mention what other
time commitments, such as school work, exams, research, another job, vacation,
etc., will you have in this period. Mention the dates for these commitments and
how many hours a week do these commitments take.*

*The Coding Period is 10 weeks long. Mention how you will schedule 175h of work
in this period. For example, working 7 hours per day you can finish in 25 days
(5 weeks).*

## Tips

Please be factual and clear in answering these questions. Feel free to
add anything else that is relevant for your application.

It is never too early to start working on your GSoC proposal!

To write a useful application, make sure what you are proposing is a
manageable and agreed-upon project.
